#
# spec file for package dd_rhelp
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           dd_rhelp
Version:        0.3.0
Release:        14.2
Summary:        Bash Helper Script That Handles dd_rescue
License:        GPL-2.0-or-later
Group:          System/Base
URL:            http://www.kalysto.org/utilities/dd_rhelp/index.en.html
Source0:        http://www.kalysto.org/pkg/%{name}-%{version}.tar.gz
Patch1:         dd_rhelp_EOF.diff
Patch2:         dd_rhelp_Summary.diff
Patch3:         dd_rhelp.test.diff
Patch4:         dd_r_version.diff
BuildRequires:  bc
BuildRequires:  dd_rescue
# dd_rhelp (version 0.1.2) was splitted from dd_rescue after openSUSE 12.1 (at dd_rescue version 1.25)
Requires:       dd_rescue > 1.24_0.1.2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
dd_rhelp is a bash helper script that handles dd_rescue. dd_rescue roughly acts
as the dd linux command with the caracteristic to NOT stop when it falls on
read/write.

dd_rhelp intelligently controls dd_rescue to first copy all blocks from areas
that work and only then tries to approach the bad spots from both sides.

%prep
%setup -q
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1

%build

%install
mkdir -p %{buildroot}%{_bindir}
install -Dpm 0755 dd_rhelp %{buildroot}%{_bindir}

%if 0%{?suse_version} < 1550
mkdir %{buildroot}/bin
ln -sf %{_bindir}/dd_rhelp %{buildroot}/bin
%endif

%check
./dd_rhelp.test

%files
%defattr(-,root,root,-)
%doc COPYING ChangeLog FAQ NEWS README THANKS TODO doc/example.txt
%{_bindir}/dd_rhelp
%if 0%{?suse_version} < 1550
/bin/dd_rhelp
%endif

%changelog
* Tue Dec 27 2022 Ludwig Nussel <lnussel@suse.com>
- Replace transitional %%usrmerged macro with regular version check (boo#1206798)
* Mon Oct 19 2020 Ludwig Nussel <lnussel@suse.de>
- prepare usrmerge (boo#1029961)
* Wed Mar 14 2018 kurt@garloff.de
- dd_r_version.diff: Make dd_rhelp accept version 1.99.x.
* Sat Mar  8 2014 kurt@garloff.de
- Update dd_rhelp_EOF.diff to support dd_rescue-1.41+.
* Sun Feb  3 2013 kurt@garloff.de
- Apply three fixes:
  * dd_rhelp_EOF.diff: Be tolerant to error messages after EOF.
  * dd_rhelp_Summary.diff: Avoid misparsing Summary line.
  * dd_rhelp.test.diff: Don't misparse dd_rescue version number.
* Mon Apr 23 2012 asterios.dramis@gmail.com
- Update to version 0.3.0:
  * new: fix of some macos bugs
  * fix: handfull of little buts where fixed as usual.
  * fix: several patches from Kurt Garloff were merged.
  From version 0.2.0:
  * new: macosx support will use BSD sed and BSD stat
  * new: main algo is somewhat cleverer than before by going first
    forward then backwards and choosing a bias to favor forward
    dd_rescueing which is often much quicker.
  * new: big efforts on the testing bed for dd_rhelp.
  * imp: efforts to add some consistency checks all around.
  * imp: some effort to cache some values results in some soft speed
    ameliorations.
  * fix: handfull of little bugs where fixed.
  * fix: correctly handle strange behavior where EINVAL is sent in
    place of EOF
- Removed all previous patches (since they are merged upstream or fixed
  otherwise).
* Wed Mar 14 2012 asterios.dramis@gmail.com
- Added dd_rhelp_largedisk.diff patch (change parsing from dd_rhelp to support
  positions / sizes > 1TB).
* Mon Mar  5 2012 asterios.dramis@gmail.com
- dd_rhelp became a separate package (splitted from dd_rescue).
* Tue Feb  7 2012 rschweikert@suse.com
- place binaries in /usr tree (UsrMerge project)
* Wed Oct  5 2011 garloff@suse.de
- Update to dd_rescue-1.24:
  * Handle directory as output filename (append input basename).
- Fix dd_rhelp.test script and add to %%check.
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
* Sat Sep  3 2011 asterios.dramis@gmail.com
- Spec file updates:
  * Changed License: to GPL-2.0 (bnc#714914).
  * Minor other updates.
* Sat May 14 2011 asterios.dramis@gmail.com
- Update to dd_rhelp-0.1.2:
  * IMPROVEMENT : will check the log file destination for sane conditions and
    will try some other locations if not.
  * IMPROVEMENT : will manage max_err parameter to avoid creating to much
    chunks.
  * More and better information displayed at 'info' time.
  From dd_rhelp-0.1.0:
  * INSTALL : No more ./configure && make && make install ... all detection
    were done at runtime anyway
  * UPDATE : updated libs provided in dd_rhelp
  * UPDATE : finally compatible with recent tail/head "-n" arguments
  * Added some sanity tests.
  * TEST : Started to create dd_rhelp.test which unit tests dd_rhelp.
- Spec file updates:
  * Changes based on rpmdevtools templates and spec-cleaner run.
  * Added description for the patches based on openSUSE Patches Guidelines.
  * Added a fix inside the spec file to remove build time references
  * dd_rhelp no longer needs auto* tools.
  * Minor other updates.
- Removed dd_rhelp_src.diff patch (fixed upstream).
- Rebased the other patches to apply cleanly.
* Tue Nov  2 2010 garloff@suse.de
- Move autoconf/configure stuff to %%build section.
* Thu Oct 14 2010 garloff@suse.de
- Adapt BuildRequires to new naming of libfallocate-devel-static.
* Mon Oct 11 2010 garloff@suse.de
- dd_rescue-1.23:
  * A short read (because of EOF) is not regarded an error anymore.
    This fixes confusing exit codes as well as non-quietness for -q.
  * We now REALLY default to -y0.
* Wed Sep  8 2010 garloff@suse.de
- dd_rescue-1.22:
  * Display compiler, compile time, enabled options.
  * If hardbs == softbs, don't repeat copy attempts.
  * Fix FPE in progress bar for non-seekable input reverse copy.
  * Document some of the goodies in the README.
  * Make code more digestable for non-GCC compilers, optional
    fallbacks for strsignal, pread, pwrite.
* Mon Aug 30 2010 garloff@suse.de
- dd_rescue 1.21:
  * Display warnings when using sparse writing.
* Sun Aug 22 2010 garloff@suse.de
- dd_rescue 1.20:
  * Update docs to document the overwrite disk with itself case
  * Also display progress bar if we know that the copy size due
    to -m.
* Sat Aug 21 2010 garloff@suse.de
- Really fix dd_rhelp to not break on new Summary line.
* Sat Aug 21 2010 garloff@suse.de
- Update to dd_rescue-1.19:
  * Fix 32bit screwup with display of total amount of date to copy
  * Support fallocate (using libfallocate) with -P (Prealloc)
  * More consistent use of ddrescue: (info): prefix (splice, Summary)
  * dd_rhelp adjusted for Summary change.
* Fri Aug 13 2010 garloff@suse.de
- Update to dd_rescue-1.18:
  * Change default for sync to -y0.
- Update to dd_rescue-1.17:
  * Display progress bar, percent completion and ETA
  * Better estimte current vs. avg speed
  * Exit on ENOSPC on target
  * Warn ONCE on EINVAL for fsync
- Update to dd_rescue-1.16:
  * Determine and display total amount of data to copy
* Fri Aug 13 2010 garloff@suse.de
- Adjust dd_rhelp to changes in dd_rescue.
* Fri Aug 13 2010 garloff@suse.de
- Update to dd_rescue-1.15:
  * Support for splice() to do zerocopy file copies
  * Better information on warnings and errors
  * Avoid repeated warning on fsync returning EINVAL
* Fri Aug 13 2010 garloff@suse.de
- Rename package to dd_rescue.
* Wed Aug 29 2007 garloff@suse.de
- Update to dd_rescue-1.14:
  * Fix bug with sparse (-a) mode that could lead to the target
    file not having the correct size.
* Mon Mar 19 2007 garloff@suse.de
- Update to dd_rescue-1.13:
  * Write full block of '0' for read errors and non-seekable
    output. (#255671)
* Mon Nov  6 2006 garloff@suse.de
- dd_rhelp: head/tail require -n option (thanks to Bryant Ling)
- dd_rhelp: Use -y0 if ddrescue is 1.12 or newer.
- dd_rhelp: Require bc.
* Fri Jul 28 2006 garloff@suse.de
- Update to dd_rescue-1.12:
  * Option -b: Log bad blocks to ASCII file
  * Option -y: Change fsync frequency (performance)
* Mon May 22 2006 schwab@suse.de
- Don't strip binaries.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Feb 21 2005 garloff@suse.de
- Add autoreconf to dd_rhelp.
* Mon Feb 14 2005 garloff@suse.de
- Update to dd_rescue-1.11:
  * O_DIRECT needs aligned buffers (Raymund Will)
  * Compile fix for systems without O_DIRECT
- Update to dd_rhelp 0.06
* Sat Aug 28 2004 garloff@suse.de
- Update to dd_rescue-1.10:
  * Support for non-seekable in-/output (pipes).
* Sat Aug 28 2004 garloff@suse.de
- Update to dd_rescue-1.04:
  * Include fix from Lab Valentin for dd_rhelp
  * Fix CPU load display overflow
  * Default soft block size now 64k instead of 16k
  * O_DIRECT supported (-d/-D)
  * option -p to copy permissions/owner/times
- Include dd_rhelp script (0.0.5) from Lab Valentin.
* Thu Jul 26 2001 garloff@suse.de
- Update to version 1.02:
  * Better handling of partially successful reads.
  * Don't loop on EFBIG when writing.
  * Avoid errno checking if not necessary.
* Mon Apr 30 2001 garloff@suse.de
- Bugfix release 1.01:
  * Don't loop trying to write to full partition (ENOSPC)
  * Fix compiler format warning (\%% -> %%%%)
  * Add lots of const qualifiers
  * Optimize block zero checking routine
* Fri Feb  9 2001 garloff@suse.de
- #include <stdarg.h> to fix compilation error on variadic fns
* Sat Dec  9 2000 nashif@suse.de
-  sorted
* Wed Aug 30 2000 garloff@suse.de
- Update to 1.00: Some preparation for supporting non-seekable
  in- or output. No support yet: Print warning and abort.
* Fri May 26 2000 garloff@suse.de
- Update to 0.99: Use stderr to print messages instead of stdout
- Prepare allowing - as stdin/stdout (but pread/pwrite() will fail)
- Fix spelling in README
- Use BuildRoot
* Fri Jan 14 2000 garloff@suse.de
- Fixed README.dd_rescue.
* Wed Oct 27 1999 garloff@suse.de
- Removed flushb. It belongs into util-linux.
* Tue Oct 19 1999 garloff@suse.de
- Fixed typo in help. (b <-> B)
* Fri Oct 15 1999 garloff@suse.de
- Initial release: 0.98.
